@@ -22,74 +22,57 @@
 # Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
 #-------------------------------------------------------------------------
 
-
+require 'jsmin.php';
 class ScriptDeploy extends CMSModule
 {
-
 	function GetName(){
 		return get_class($this);
 	}
-	
 	function GetFriendlyName(){
 		return $this->Lang('friendlyname');
 	}
-	
 	function GetVersion(){
-		return '0.2';
+		return '0.3';
 	}
-	
 	function GetHelp(){
 		return $this->Lang('help');
 	}
-	
 	function GetAuthor(){
 		return 'jeremyBass';
 	}
-	
 	function GetAuthorEmail(){
 		return 'jeremybass@cableone.net';
 	}
-	
 	function GetChangeLog(){
 		return $this->Lang('changelog');
 	}
-	
 	function IsPluginModule(){
 		return true;
 	}
-	
 	function HasAdmin(){
 		return true;
 	}
-	
 	function GetAdminSection(){
 		return 'extensions';
 	}
-	
 	function GetAdminDescription(){
 		return $this->Lang('moddescription');
 	}
-	
 	function VisibleToAdminUser(){
 		return $this->CheckPermission('Modify Calendar');
 	}
-	
 	function GetDependencies(){
 		return array();
 	}
-	
 	function MinimumCMSVersion(){
 		return "1.6.6";
 	}
-	
 	function InstallPostMessage(){
 		return $this->Lang('postinstall');
 	}
-	
 	function UninstallPostMessage(){
 		return $this->Lang('postuninstall');
 	}
-
 	function UninstallPreMessage(){
 		return false;//$this->Lang('really_uninstall');
 	}
@@ -123,10 +106,8 @@ class ScriptDeploy extends CMSModule
 		return true;
 	}
 
-
-/*----------------------------------------------------*/
 /*----Do-final-output-steps---------------------------*/
-/*----------------------------------------------------*/
+
 	function filestime($ID,$type){
 		global $gCms;
 		$config =& $gCms->GetConfig(); 
@@ -138,6 +119,7 @@ class ScriptDeploy extends CMSModule
 				$codeToFile=$ScriptIs;
 			}
 			if($pathOption!=''){
+				$pathOption=$config['root_path'].$pathOption;
 				$codeToFile=file_get_contents($pathOption);
 			}
 		}elseif($type=="groupID"){
@@ -149,6 +131,7 @@ class ScriptDeploy extends CMSModule
 					'.$ScriptIs;
 				}
 				if($pathOption!=''){
+					$pathOption=$config['root_path'].$pathOption;
 					$codeToFile.='
 					'.file_get_contents($pathOption);
 				}
@@ -158,29 +141,15 @@ class ScriptDeploy extends CMSModule
 			$type=$scriptType;
 		}
 		if($smartyOn==1){
-			$string = $codeToFile; 
-			$pattern = '/\{/'; 
-			$replacement = '^^^'; 
-			$string = preg_replace($pattern, $replacement, $string); 
-			$pattern = '/\}/'; 
-			$replacement = '***'; 
-			$string = preg_replace($pattern, $replacement, $string); 
-			$pattern = '/:::([.$_a-z0-9\s-]*):::/'; 
-			$replacement = '{$1}'; 
-			$string = preg_replace($pattern, $replacement, $string);
-			$string=$this->ProcessTemplateFromData($string); 
-			$pattern = '/\^\^\^/'; 
-			$replacement = '{'; 
-			$string = preg_replace($pattern, $replacement, $string); 
-			$pattern = '/\*\*\*/'; 
-			$replacement = '}'; 
-			$string = preg_replace($pattern, $replacement, $string); 
-			$codeToFile=$string; 
+			$this->smarty->left_delimiter = '{{';
+			$this->smarty->right_delimiter = '}}';
+			$codeToFile=$this->ProcessTemplateFromData($codeToFile); 
+			$this->smarty->left_delimiter = '{';
+			$this->smarty->right_delimiter = '}';
 		}
 		$ouput = array($codeToFile,$type);
 		return $ouput;
 	}
-
 /**
 * Display a simple message
 */
@@ -247,12 +216,9 @@ class ScriptDeploy extends CMSModule
 		unset( $params['action'] );
 		$this->Redirect( $id, $action, '', $params );
 	}
-	
-	
-	
-/*----------------------------------------------------*/
+
+
 /*----Makeing-all-the-Selections--DB-calls------------*/
-/*----------------------------------------------------*/		
 	function TieAScript($action='select',$scriptID='',$GrouptSetID=''){
 		$db =& $this->GetDb();
 		$retresult = array();
@@ -262,9 +228,9 @@ class ScriptDeploy extends CMSModule
 		$this->FireDebug('message',$GrouptSetID);//<<<<------Fire PHP message
 		$r='';
 		
-		/*--------------------------*/
+		
 		/*------Pull-A-Script-------*/
-		/*--------------------------*/
+		
 		if($action=='select'){
 			
 			$db =& $this->GetDb();
@@ -288,14 +254,16 @@ class ScriptDeploy extends CMSModule
 				$results['ScriptIs']= $result->fields['ScriptIs'];
 				$results['scriptType']= $result->fields['scriptType'];
 				$results['scriptSize']= $result->fields['scriptSize'];
+				$results['notes']= $result->fields['notes'];
+				$results['MediaType']= $result->fields['MediaType'];
 				$retresult[$daKey] = $results;
 				$result->MoveNext();
 			}
 			$this->FireDebug('message','Results '.$retresult[$scriptID]);//<<<<------Fire PHP message
 			return $retresult[$scriptID];		
-		/*--------------------------*/
+		
 		/*--Pull-A-List-Of-Scripts--*/
-		/*--------------------------*/
+		
 		}elseif($action=='selectList'){
 			$this->FireDebug('message','Got here');//<<<<------Fire PHP message
 			$db =& $this->GetDb();
@@ -315,13 +283,15 @@ class ScriptDeploy extends CMSModule
 				$results['pathOption']= $result->fields['pathOption'];
 				$results['scriptType']= $result->fields['scriptType'];
 				$results['scriptSize']= $result->fields['scriptSize'];
+				$results['notes']= $result->fields['notes'];
+				$results['MediaType']= $result->fields['MediaType'];
 				$retresult[$daKey] = $results;
 				$result->MoveNext();
 			}
 			return $retresult;
-		/*--------------------------*/
+		
 		/*--Pull-A-List-Of-Groups---*/
-		/*--------------------------*/
+		
 		}elseif($action=='selectGroupList'){
 			
 			$db =& $this->GetDb();
@@ -329,8 +299,8 @@ class ScriptDeploy extends CMSModule
 			$retresult = array();
 			$results = array();	
 
-			$query = 'SELECT * FROM '.cms_db_prefix().'module_ScriptDeploy_Group AS sdG '
-				.'LEFT JOIN '.cms_db_prefix().'module_ScriptDeploy_GroupAssignMent AS sdGm ON sdG.ID = sdGm.GrouptSetID';
+			$query = 'SELECT * FROM '.cms_db_prefix().'module_scriptdeploy_group AS sdG '
+				.'LEFT JOIN '.cms_db_prefix().'module_scriptdeploy_groupassignment AS sdGm ON sdG.ID = sdGm.GrouptSetID';
 			$result = &$db->Execute($query);
 
 			while ($result && !$result->EOF){
@@ -348,35 +318,37 @@ class ScriptDeploy extends CMSModule
 				$result->MoveNext();
 			}
 			return $retresult;
-		/*--------------------------*/
+		
 		/*----Pull-A-Groups-List----*/
-		/*--------------------------*/
+		
 		}elseif($action=='selectGroupsListings'){
 			$this->FireDebug('message','Got here');//<<<<------Fire PHP message
-			$db =& $this->GetDb();
+			$db = $this->GetDb();
 		
 			$retresult = array();
 			$results = array();	
 
-			$query = 'SELECT ScriptSet,scriptSize,ScriptID FROM '.cms_db_prefix().'module_ScriptDeploy_Group AS sdG '
-				.'LEFT JOIN '.cms_db_prefix().'module_ScriptDeploy_GroupAssignMent AS sdGm ON sdG.ID = sdGm.GrouptSetID '
+			$query = 'SELECT sn.ScriptSet,so.scriptSize,sdGm.ScriptID,sdGm.ScriptORDER FROM '.cms_db_prefix().'module_scriptdeploy_group AS sdG '
+				.'LEFT JOIN '.cms_db_prefix().'module_scriptdeploy_groupassignment AS sdGm ON sdG.ID = sdGm.GrouptSetID '
 				.'LEFT JOIN '.cms_db_prefix().'module_scriptdeploy_scriptoptions AS so ON so.ID = sdGm.ScriptID '
 				.'LEFT JOIN '.cms_db_prefix().'module_scriptdeploy_scriptnames AS sn ON so.ID = sn.ID '
 				.'WHERE sdG.ID = '.$scriptID.'';
-			$result = &$db->Execute($query);
-		
+			$result = $db->Execute($query);
+			
 			while ($result && !$result->EOF){
 				$daKey=$result->fields['ScriptID'];
 				$results['ScriptSet']= $result->fields['ScriptSet'];
 				$results['scriptSize']= $result->fields['scriptSize'];
+				$results['ScriptORDER']= $result->fields['ScriptORDER'];
 				$retresult[$daKey] = $results;
 				$result->MoveNext();
 			}
+			
 			return $retresult;
 			
-		/*--------------------------*/
+		
 		/*----Pull-A-Groups-List----*/
-		/*--------------------------*/
+		
 		}elseif($action=='selectGroup'){
 			$this->FireDebug('message','Got here');//<<<<------Fire PHP message
 			$db =& $this->GetDb();
@@ -384,7 +356,7 @@ class ScriptDeploy extends CMSModule
 			$retresult = array();
 			$results = array();	
 
-			$query = 'SELECT * FROM '.cms_db_prefix().'module_ScriptDeploy_Group AS sdG '
+			$query = 'SELECT * FROM '.cms_db_prefix().'module_scriptdeploy_group AS sdG '
 				.'WHERE sdG.ID = '.$scriptID.'';
 			$result = &$db->Execute($query);
 		
@@ -399,9 +371,9 @@ class ScriptDeploy extends CMSModule
 			}
 			return $retresult[$scriptID];	
 			
-		/*--------------------------*/
+		
 		/*----Pull-A-Groups-List-#--*/
-		/*--------------------------*/
+		
 		}elseif($action=='selectGroupItems'){
 			$this->FireDebug('message','Got here');//<<<<------Fire PHP message
 			$db =& $this->GetDb();
@@ -410,18 +382,17 @@ class ScriptDeploy extends CMSModule
 			$results = array();	
 
 			$query = 'SELECT ScriptID FROM '.cms_db_prefix().'module_scriptdeploy_groupassignment AS sdGm '
-				.'WHERE sdGm.GrouptSetID = '.$scriptID.'';
+				.'WHERE sdGm.GrouptSetID = '.$scriptID.' ORDER BY ScriptORDER ASC';
 			$result = &$db->Execute($query);
 			while ($result && !$result->EOF){
 				array_push($results, $result->fields['ScriptID']);
 				$result->MoveNext();
 			}
 			return $results;	
-			
 
-		/*--------------------------*/
+		
 		/*----Check-For-A-Script----*/
-		/*--------------------------*/
+		
 		}elseif($action=='selectGroupSNUM'){
 			$this->FireDebug('message','Got here');//<<<<------Fire PHP message
 			$db =& $this->GetDb();
@@ -440,11 +411,11 @@ class ScriptDeploy extends CMSModule
 			return $sciptnumber;	
 			
 
-		/*--------------------------*/
+		
 		/*----Check-For-A-Script----*/
-		/*--------------------------*/
+		
 		}elseif($action=='CheckScript'){
-			$query = 'SELECT * FROM '.cms_db_prefix().'module_ScriptDeploy_GroupAssignMent '
+			$query = 'SELECT * FROM '.cms_db_prefix().'module_scriptdeploy_groupassignment '
 				.'WHERE ScriptID='.$scriptID.' AND GrouptSetID='.$GrouptSetID.'';
 			$result = &$db->Execute($query);
 				if($result && !$result->EOF){$r=$scriptID;}else{$r='';}
@@ -453,9 +424,9 @@ class ScriptDeploy extends CMSModule
 		}			
 	}
 	
-/*----------------------------------------------------*/
+
 /*----Get-the-set-of-the-file-------------------------*/
-/*----------------------------------------------------*/	
+	
 	function SizeItUp($size){
 	 if($size < 1024){
 		  $size2="$size bytes";
@@ -472,9 +443,9 @@ class ScriptDeploy extends CMSModule
 	}
 
 
-/*----------------------------------------------------*/
+
 /*----Script-List-Set-up------------------------------*/
-/*----------------------------------------------------*/
+
 
 	
 	function _AdminCreateTemplateList( $id, $returnid, $prefix, $defaulttemplatepref, 
@@ -498,13 +469,8 @@ class ScriptDeploy extends CMSModule
 			$maxAge= $onedbProfile['maxAge'];
 			$pathOption= $onedbProfile['pathOption'];
 			$scriptType= $onedbProfile['scriptType'];
-			$scriptSize= $onedbProfile['scriptSize'];	
-		 
+			$scriptSize= $onedbProfile['scriptSize'];
 			$row = new StdClass();
-			
-			
-			
-			
 			$row->name = $this->CreateLink( $id, 'edittemplate', $returnid,
 							$key, array('ScriptSet' => $key,
 									'active_tab' => $active_tab,
@@ -565,13 +531,10 @@ class ScriptDeploy extends CMSModule
 		$this->smarty->assign($this->CreateFormEnd());
 		echo $this->ProcessTemplate('edittemplates.tpl');
 	}
-	
-	
-	
-	
-/*----------------------------------------------------*/
+
+
 /*----Group-List-Set-up-------------------------------*/
-/*----------------------------------------------------*/
+
 
 	function _AdminCreateAssignmentList( $id, $returnid, $prefix, $defaulttemplatepref, 
 						 $active_tab, $defaultprefname,
@@ -651,18 +614,5 @@ class ScriptDeploy extends CMSModule
 		$this->smarty->assign($this->CreateFormEnd());
 		echo $this->ProcessTemplate('editAssignments.tpl');
 	}
-	
-	function post_it($datastream, $url){ 
-		$url = preg_replace("@^http://@i", "", $url); 
-		$host = substr($url, 0, strpos($url, "/")); 
-		$uri = strstr($url, "/");
-		$reqbody = ""; 
-		foreach($datastream as $key=>$val){ 
-			if (!($reqbody=='')) $reqbody.= "&"; 
-			$reqbody.= $key."=".urlencode($val); 
-		}
-		header("Location: http://$host$uri?$reqbody"); die;
-		return $result; 
-	}
 }
 ?>
